<?php
// Fungsi untuk membuat robots.txt
function createRobotsTxt($baseUrl, $folderNames) {
    // Konten untuk robots.txt yang mengizinkan mesin pencari mengakses semua bagian situs
    $robotsContent = "User-agent: *\nDisallow:\nAllow: /\nSitemap: {$baseUrl}/sitemap.xml";
    // Simpan robots.txt di root direktori
    file_put_contents("robots.txt", $robotsContent);
    echo "File robots.txt telah dibuat.<br>";
}

// Fungsi untuk membuat sitemap.xml
function createSitemapXml($baseUrl, $folderNames) {
    // Mulai pembuatan sitemap.xml
    $sitemapContent = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
    $sitemapContent .= "<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\">\n";

    // Menambahkan URL utama ke sitemap
    $sitemapContent .= "  <url>\n";
    $sitemapContent .= "    <loc>{$baseUrl}</loc>\n"; // URL utama
    $sitemapContent .= "    <lastmod>" . date("Y-m-d") . "</lastmod>\n";
    $sitemapContent .= "    <changefreq>daily</changefreq>\n";
    $sitemapContent .= "    <priority>1.0</priority>\n";
    $sitemapContent .= "  </url>\n";

    // Menambahkan URL folder ke sitemap
    foreach ($folderNames as $folderName) {
        $sitemapContent .= "  <url>\n";
        $sitemapContent .= "    <loc>{$baseUrl}{$folderName}/</loc>\n"; // URL folder
        $sitemapContent .= "    <lastmod>" . date("Y-m-d") . "</lastmod>\n";
        $sitemapContent .= "    <changefreq>weekly</changefreq>\n";
        $sitemapContent .= "    <priority>0.9</priority>\n";
        $sitemapContent .= "  </url>\n";
    }

    $sitemapContent .= "</urlset>";

    // Simpan sitemap.xml di root direktori
    file_put_contents("sitemap.xml", $sitemapContent);
    echo "File sitemap.xml telah dibuat.<br>";
}

// Ambil URL dasar dari konfigurasi atau hardcode
$baseUrl = "https://ctgreport.com/";  // Gantilah dengan domain situs Anda
$folderNames = isset($argv) && isset($argv[1]) ? explode(',', $argv[1]) : []; // Mengambil nama folder sebagai parameter

// Pastikan bahwa folderNames tidak kosong
if (empty($folderNames)) {
    echo "Tidak ada folder yang diberikan. Pastikan Anda sudah membuat folder atau mengirimkan folder sebagai parameter.\n";
    exit;
}

// Panggil fungsi untuk membuat robots.txt dan sitemap.xml
createRobotsTxt($baseUrl, $folderNames);
createSitemapXml($baseUrl, $folderNames);
?>